Reference
=========

.. currentmodule:: pyobo

.. autoclass:: Reference
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~Reference.bioregistry_link

   .. rubric:: Methods Summary

   .. autosummary::

      ~Reference.auto
      ~Reference.from_curie
      ~Reference.from_iri
      ~Reference.validate_prefix

   .. rubric:: Attributes Documentation

   .. autoattribute:: bioregistry_link

   .. rubric:: Methods Documentation

   .. automethod:: auto
   .. automethod:: from_curie
   .. automethod:: from_iri
   .. automethod:: validate_prefix
